Hi @tilly ,
Thanks for the update! Oddly enough, there was an even bigger change on your end which no one has bothered to mention: the visitor.js bundle has been greatly reduced in size as everyone has been requesting, all the way from ~1.39MB to 246kB! This is the degree of minification which we’d been saying should’ve been possible since 2 1/2 years ago, so thank you to whichever unsung hero within HubSpot finally got this knocked out.
FYI @jennysowyrda , it turns out this was possible despite the stonewalling, as HubSpot finally took care of it (your comment didn’t age well)…
The “Time on page in seconds” trigger actually wouldn’t have resolved this issue, as visitor.js still gets loaded immediately and would’ve still had a pretty massive impact on both initial page loads and script compile times. There doesn’t appear to be any load deferred until after the time on page elapses, so our primary complaint wouldn’t have been addressed without the optimization of the visitor.js dependency.